"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

var _formatContributionType = _interopRequireDefault(require("../format-contribution-type"));

var _contributors = _interopRequireDefault(require("./fixtures/contributors.json"));

var fixtures = function () {
  return {
    options: {
      projectOwner: 'all-contributors',
      projectName: 'all-contributors-cli',
      repoType: 'github',
      repoHost: 'https://github.com',
      imageSize: 100
    }
  };
};

test('return corresponding symbol', function () {
  var contributor = _contributors.default.kentcdodds;

  var _fixtures = fixtures(),
      options = _fixtures.options;

  expect((0, _formatContributionType.default)(options, contributor, 'tool')).toBe('<a href="#tool-kentcdodds" title="Tools">🔧</a>');
  expect((0, _formatContributionType.default)(options, contributor, 'question')).toBe('<a href="#question-kentcdodds" title="Answering Questions">💬</a>');
});
test('return link to commits', function () {
  var contributor = _contributors.default.kentcdodds;

  var _fixtures2 = fixtures(),
      options = _fixtures2.options;

  var expectedLink = 'https://github.com/all-contributors/all-contributors-cli/commits?author=kentcdodds';
  expect((0, _formatContributionType.default)(options, contributor, 'code')).toBe(`<a href="${expectedLink}" title="Code">💻</a>`);
  expect((0, _formatContributionType.default)(options, contributor, 'doc')).toBe(`<a href="${expectedLink}" title="Documentation">📖</a>`);
  expect((0, _formatContributionType.default)(options, contributor, 'test')).toBe(`<a href="${expectedLink}" title="Tests">⚠️</a>`);
});
test('return link to issues', function () {
  var contributor = _contributors.default.kentcdodds;

  var _fixtures3 = fixtures(),
      options = _fixtures3.options;

  expect((0, _formatContributionType.default)(options, contributor, 'bug')).toBe('<a href="https://github.com/all-contributors/all-contributors-cli/issues?q=author%3Akentcdodds" title="Bug reports">🐛</a>');
});
test('make any symbol into a link if contribution is an object', function () {
  var contributor = _contributors.default.kentcdodds;

  var _fixtures4 = fixtures(),
      options = _fixtures4.options;

  expect((0, _formatContributionType.default)(options, contributor, {
    type: 'tool',
    url: 'www.foo.bar'
  })).toBe('<a href="www.foo.bar" title="Tools">🔧</a>');
});
test('override url for given types', function () {
  var contributor = _contributors.default.kentcdodds;

  var _fixtures5 = fixtures(),
      options = _fixtures5.options;

  expect((0, _formatContributionType.default)(options, contributor, {
    type: 'code',
    url: 'www.foo.bar'
  })).toBe('<a href="www.foo.bar" title="Code">💻</a>');
});
test('be able to add types to the symbol list', function () {
  var contributor = _contributors.default.kentcdodds;

  var _fixtures6 = fixtures(),
      options = _fixtures6.options;

  options.types = {
    cheerful: {
      symbol: ':smiley:'
    }
  };
  expect((0, _formatContributionType.default)(options, contributor, 'cheerful')).toBe('<a href="#cheerful-kentcdodds" title="">:smiley:</a>');
  expect((0, _formatContributionType.default)(options, contributor, {
    type: 'cheerful',
    url: 'www.foo.bar'
  })).toBe('<a href="www.foo.bar" title="">:smiley:</a>');
});
test('be able to add types with template to the symbol list', function () {
  var contributor = _contributors.default.kentcdodds;

  var _fixtures7 = fixtures(),
      options = _fixtures7.options;

  options.types = {
    web: {
      symbol: ':web:',
      link: 'www.<%= contributor.login %>.com'
    }
  };
  expect((0, _formatContributionType.default)(options, contributor, 'web')).toBe('<a href="www.kentcdodds.com" title="">:web:</a>');
});
test('be able to override existing types', function () {
  var contributor = _contributors.default.kentcdodds;

  var _fixtures8 = fixtures(),
      options = _fixtures8.options;

  options.types = {
    code: {
      symbol: ':smiley:'
    }
  };
  expect((0, _formatContributionType.default)(options, contributor, 'code')).toBe('<a href="#code-kentcdodds" title="">:smiley:</a>');
  expect((0, _formatContributionType.default)(options, contributor, {
    type: 'code',
    url: 'www.foo.bar'
  })).toBe('<a href="www.foo.bar" title="">:smiley:</a>');
});
test('be able to override existing templates', function () {
  var contributor = _contributors.default.kentcdodds;

  var _fixtures9 = fixtures(),
      options = _fixtures9.options;

  options.types = {
    code: {
      symbol: ':web:',
      link: 'www.<%= contributor.login %>.com'
    }
  };
  expect((0, _formatContributionType.default)(options, contributor, 'code')).toBe('<a href="www.kentcdodds.com" title="">:web:</a>');
  expect((0, _formatContributionType.default)(options, contributor, {
    type: 'code',
    url: 'www.foo.bar'
  })).toBe('<a href="www.foo.bar" title="">:web:</a>');
});
test('throw a helpful error on unknown type', function () {
  var contributor = _contributors.default.kentcdodds;

  var _fixtures10 = fixtures(),
      options = _fixtures10.options;

  expect(function () {
    return (0, _formatContributionType.default)(options, contributor, 'docs');
  }).toThrowError('Unknown contribution type docs for contributor kentcdodds');
});
test('throw a helpful error on unknown type and no login', function () {
  var contributor = _contributors.default.nologin_badrole;

  var _fixtures11 = fixtures(),
      options = _fixtures11.options;

  expect(function () {
    return (0, _formatContributionType.default)(options, contributor, 'docs');
  }).toThrowError('Unknown contribution type docs for contributor Wildly Misconfigured');
});